#
# spec file for package rust-cbindgen
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Use hardening ldflags.
%global crate_name cbindgen
%global rustflags -Clink-arg=-Wl,-z,relro,-z,now
Name:           rust-%{crate_name}
Version:        0.19.0
Release:        1.9.1
Summary:        A tool for generating C bindings from Rust code
License:        MPL-2.0
Group:          Development/Languages/Rust
URL:            https://crates.io/crates/cbindgen
Source0:        https://github.com/eqrion/cbindgen/archive/v%{version}.tar.gz#/%{crate_name}-%{version}.tar.gz
Source1:        vendor.tar.xz
BuildRequires:  cargo >= 1.32.0
BuildRequires:  rust >= 1.32.0

%description
A tool for generating C bindings from Rust code.

%prep
%setup -q -T -b 0 -n %{crate_name}-%{version}
%setup -q -D -T -a 1 -n %{crate_name}-%{version}
mkdir cargo-home
cat >cargo-home/config <<EOF
[source.crates-io]
registry = 'https://github.com/rust-lang/crates.io-index'
replace-with = 'vendored-sources'
[source.vendored-sources]
directory = './vendor'
EOF

%build
# This should eventually migrate to distro policy
# Enable optimization, debuginfo, and link hardening.
export RUSTFLAGS="%{rustflags}"
export CARGO_HOME=`pwd`/cargo-home/

cargo build --release

%install
# rustflags must be exported again at install as cargo build will
# rebuild the project if it detects flags have changed (to none or other)
export RUSTFLAGS="%{rustflags}"
# install stage also requires re-export of 'cargo-home' or cargo
# will try to download source deps and rebuild
export CARGO_HOME=`pwd`/cargo-home/
# cargo install appends /bin to the path
cargo install --root=%{buildroot}%{_prefix} --path .
# remove spurious files
rm -f %{buildroot}%{_prefix}/.crates.toml
rm -f %{buildroot}%{_prefix}/.crates2.json

%files
%license LICENSE
%{_bindir}/cbindgen

%changelog
* Mon Apr 19 2021 martin.sirringhaus@suse.com
- Update to 0.19.0
  * Simplify types in generics
  * Use --profile=check for macro expansion
  * Use exported name to prefix enum variants
  * Fix path attribute handling in inline submodules
  * Fix a stack overflow with some recursive typedefs
- Update to 0.18.0
  * Simplify types in nested types such as pointed-to types and
    function signatures
- Update to 0.17.0
  * Add with_parse_extra_bindings to builder.
  * Support NonZero and fix incorrect simplification of Option<ptr> into ptr.
  * Deal with name conflicts correctly in declaration type resolution.
  * Support pointers to ZSTs.
* Tue Jan 12 2021 martin.sirringhaus@suse.com
- Update to 0.16.0
  * Remove artificial restriction on lifetime parameters on enums
  * Add an option for converting usize/isize into size_t/ptrdiff_t.
  * Allow controlling the cargo profile used for expansion.
  * Support wider range of expressions in enum discriminants
  * Support generation of Cython bindings
  * Fixed some issues with style=tag and recursive structs
  * Default C style to Both (as specified in docs)
  * Fix resolution of path dependencies from certain modules.
  * Support inlined definitions for tuple variants with a single field in C
* Tue Oct 13 2020 martin.sirringhaus@suse.com
- update to 0.15.0
  * Allow customizing mangling of generic parameters in C
  * Box<T> simplifies to T* in C
  * ManuallyDrop<T> and MaubeUninit<T> simplify to T in C, and are opaque in C++
  * C++ supports a derive-ostream annotation to derive serialization
    of structs, unions and enums
  * Large character constants have been fixed on Windows
  * Constants are now generated for typedefs, etc
  * The `sort_by` configuration option has been made to work for constants
  * Default sort order is source order now (sort_by = "None"), and can
    be changed by the above option
- update to 0.14.6
  * Fixed the builds with older versions of rustc.
- update to 0.14.5
  * Add support to specify line ending style
  * Add cbindgen:ptrs-as-arrays annotation to allow making function
    arguments C/C++ arrays.
- update to 0.14.4
  * Allow to override the mangling separator
  * cbindgen now handles better having ZSTs in template parameters, and
    default template parameters.
  * Support for annotating nonnull pointers
  * Fixed bitflags that overflow a signed integer
  * Support for wildcard argument names
  * Support for the never return type, with configurable annotation
  * Properly reject arrays as function arguments
* Thu Jul 23 2020 wr@rosenauer.org
- update to 0.14.3
  * Introduce cbindgen:ignore comment annotation, to allow ignoring items or modules.
  * Support for casts in constant expressions.
  * Make a non-fatal error a warning message.
  * Add a --metadata option to the CLI, to allow passing pre-computed cargo metadata.
  0.14.2
  * Fixed minimal dependency versions.
  * Add an option to write pragma once.
  * Fix submodule scanning for implicit Rust 2018 modules.
  * Fix dependency parsing / scanning to handle target-specific versions.
  * Use heck for case conversion.
  * Add support for verbatim content after includes.
  * Allow to add attributes to most generated functions.
* Wed Apr 15 2020 martin.sirringhaus@suse.com
- update to version 0.14.1
  * Handle mangling pointers.
  * Unconditionally generate a return statement in partialeq
    implementations.
- update to version 0.14.0
  * Minor tweak at how [export.exclude] is handled to allow
    excluding generic instantiations in C mode.
  * Documented cpp_compat option.
  * Fixed a panic when parsing associated constants for a
    built-in type.
- update to version 0.13.2
  * Constants now have suitable documentation.
  * Fixed some C warnings by emitting void when there are
    no arguments.
  * Avoids reading cargo.toml when not needed, which can cause
    panics in workspace situations.
  * Only write `default` cases if the switch is not exhaustive.
  * Some warnings have been refined.
  * Code generation for static arrays has been fixed.
  * Opt-in support for constexpr in constants.
  * Fix C code generation and some warnings when extremely
    large constants are used.
  * Proper escaping of enum variants and fields.
  * Added support for RefCell (as an opaque type) and Cell.
* Thu Feb 27 2020 martin.sirringhaus@suse.com
- update to version 0.13.1
  * Support `#[cfg]` on individual enum variants.
- update to version 0.13.0
  * Support 'swift_name' attributes on generated functions
  * Add [export.pre_body] to config
  * Handle new line in doc attribute
  * Add support for `Self` in tagged enums, structs and unions
  * Make sentinel variant respect regular config
  * Fix layout of tagged enums with size under some configurations
  * Add an option to allow configuring the order of function names
    in generated headers
* Fri Jan 17 2020 martin.sirringhaus@suse.com
- update to version 0.12.2
  * Fixed version detection with lockfile v2.
  * Added support for export_name on functions.
- update to version 0.12.1
  * Added support for #[repr*64)] on enums.
  * Added support to generate plain enums instead of enum
    classes for C++.
  * Fixed dependency resolution with lockfile v2.
- update to version 0.12.0
  * Added support for #[repr(align)] and #[repr(packed)] on
    structs and unions.
  * Added support to generate copy-assignment operators for
    enums.
- update to version 0.11.1
  * More binary operators and expressions are supported.
  * More built-in bitflags operators.
- update to version 0.11.0
  * Made rust char map to uint32_t.
- update to version 0.10.1
  * Improved error message for missing config file.
  * Add missing header for char32_t.
- update to version 0.10.0
  * Initialize struct literal with list-initializer for C++11
    standard.
  * Surround namespace with __cplusplus ifdef in cpp_compat
    mode.
  * Add support for --quiet flag.
  * Map char to char32_t.
  * Improve binding_crate_ref() error message.
  * avoid prematurely returning during expansion.
  * Add support for adding "using namespace" statements.
* Fri Oct 18 2019 wr@rosenauer.org
- Update to version 0.9.1
  * Various improvements to comment output.
  * Fixed expand when ran from build.rs.
  * More debugging output for expansion.
  * New option to add a default private constructor in C++ tagged enums.
  * Syn and related dependencies updated to 1.0.
* Thu Aug  8 2019 luke@ljones.dev
- Update to version 0.9.0
  * Support to generate C headers with C++ compatibility
  * Fix include guard generation when no_includes is set
  * Fix crate parsing order so that types from the binding crate
    are preferred in presence of conflicting names
  * Add extra_bindings option to generate bindings for dependencies
  * Clap dependency is optional now so it's feasible to avoid
    building it if cbindgen is used as a library
* Tue May 14 2019 wr@rosenauer.org
- update to version 0.8.7
  * there is no upstream changelog provided
* Sun Mar 17 2019 wr@rosenauer.org
- update to version 0.6.8 to satisfy Firefox 66.0 build requirements
* Mon Nov 19 2018 astieger@suse.com
- use a source URL
* Wed Nov 14 2018 jones_ld@protonmail.com
- Initial packaging - boo#1115645
